# **Clustering** [![](https://gitee.com/tyoui/logo/raw/master/logo/photolog.png)][1]

## 数据聚类模块
[![](https://img.shields.io/badge/个人网站-jtyoui-yellow.com.svg)][1]
[![](https://img.shields.io/badge/Python-3.6-green.svg)]()
[![](https://img.shields.io/badge/BlogWeb-Tyoui-bule.svg)][1]
[![](https://img.shields.io/badge/Email-jtyoui@qq.com-red.svg)]()
[![](https://img.shields.io/badge/聚类-clustering-black.svg)]()


#### 安装
    pip install jtyoui

***
[1]: https://blog.jtyoui.com